searchData={"items":[{"type":"module","title":"FunWithFlags.UI","doc":"FunWithFlags.UI, a web dashboard for the [FunWithFlags](https://github.com/tompave/fun_with_flags) package.\n\nSee the [Readme](/fun_with_flags_ui/readme.html#how-to-run) for more detailed instructions.","ref":"FunWithFlags.UI.html"},{"type":"function","title":"FunWithFlags.UI.run_standalone/0","doc":"Convenience function to simply run the Plug in Cowboy.\n\nThis _will_ be supervided, but in the private supervsion tree\nof :cowboy and :ranch.","ref":"FunWithFlags.UI.html#run_standalone/0"},{"type":"function","title":"FunWithFlags.UI.run_supervised/0","doc":"Convenience function to run the Plug in a custom supervision tree.\n\nThis is just an example. If you actually need this, you might want\nto use your own supervision setup.","ref":"FunWithFlags.UI.html#run_supervised/0"},{"type":"module","title":"FunWithFlags.UI.Router","doc":"A `Plug.Router`. This module is meant to be plugged into host applications.\n\nSee the [Readme](/fun_with_flags_ui/readme.html#how-to-run) for more detailed instructions.","ref":"FunWithFlags.UI.Router.html"},{"type":"function","title":"FunWithFlags.UI.Router.init/1","doc":"","ref":"FunWithFlags.UI.Router.html#init/1"},{"type":"extras","title":"FunWithFlags.UI","doc":"# FunWithFlags.UI\n\n[![Mix Tests](https://github.com/tompave/fun_with_flags_ui/workflows/Mix%20Tests/badge.svg)](https://github.com/tompave/fun_with_flags_ui/actions?query=branch%3Amaster)\n[![Code Quality](https://github.com/tompave/fun_with_flags_ui/actions/workflows/quality.yml/badge.svg?branch=master)](https://github.com/tompave/fun_with_flags_ui/actions/workflows/quality.yml?query=branch%3Amaster)  \n[![Hex.pm](https://img.shields.io/hexpm/v/fun_with_flags_ui.svg)](https://hex.pm/packages/fun_with_flags_ui)\n\nA Web dashboard for the [FunWithFlags](https://github.com/tompave/fun_with_flags) Elixir package.\n\n![](https://raw.githubusercontent.com/tompave/fun_with_flags_ui/master/demo/demo.gif)","ref":"readme.html"},{"type":"extras","title":"How to run - FunWithFlags.UI","doc":"`FunWithFlags.UI` is just a plug and it can be run in a number of ways.\nIt's primarily meant to be embedded in a host Plug application, either Phoenix or another Plug app.\n\n#","ref":"readme.html#how-to-run"},{"type":"extras","title":"Mounted in Phoenix - FunWithFlags.UI","doc":"The router plug can be mounted inside the Phoenix router with [`Phoenix.Router.forward/4`](https://hexdocs.pm/phoenix/Phoenix.Router.html#forward/4).\n\n```elixir\ndefmodule MyPhoenixAppWeb.Router do\n  use MyPhoenixAppWeb, :router\n\n  pipeline :mounted_apps do\n    plug :accepts, [\"html\"]\n    plug :put_secure_browser_headers\n  end\n\n  scope path: \"/feature-flags\" do\n    pipe_through :mounted_apps\n    forward \"/\", FunWithFlags.UI.Router, namespace: \"feature-flags\"\n  end\nend\n```\n\nNote: There is no need to add `:protect_from_forgery` to the `:mounted_apps` pipeline because this package already implements CSRF protection. In order to enable it, your host application must use the `Plug.Session` plug, which is usually configured in the endpoint module in Phoenix.\n\n#","ref":"readme.html#mounted-in-phoenix"},{"type":"extras","title":"Mounted in another Plug application - FunWithFlags.UI","doc":"Since it's just a plug, it can also be mounted into any other Plug application using [`Plug.Router.forward/2`](https://hexdocs.pm/plug/Plug.Router.html#forward/2).\n\n```elixir\ndefmodule Another.App do\n  use Plug.Router\n  forward \"/feature-flags\", to: FunWithFlags.UI.Router, init_opts: [namespace: \"feature-flags\"]\nend\n```\n\nNote: If your plug router uses `Plug.CSRFProtection`, `FunWithFlags.UI.Router` should be added before your CSRF protection plug because it already implements its own CSRF protection. If you declare `FunWithFlags.UI.Router` after, your CSRF plug will likely block GET requests for the JS assets of the dashboard.\n\n#","ref":"readme.html#mounted-in-another-plug-application"},{"type":"extras","title":"Standalone - FunWithFlags.UI","doc":"Again, because it's just a plug, it can be run [standalone](https://hexdocs.pm/plug/readme.html#supervised-handlers).\n\nIf you clone the repository, the library comes with two convenience functions to accomplish this:\n\n```elixir\n# Simple, let Cowboy sort out the supervision tree:\n{:ok, pid} = FunWithFlags.UI.run_standalone()\n\n# Uses some explicit supervision configuration:\n{:ok, pid} = FunWithFlags.UI.run_supervised()\n```\n\nThese functions come in handy for local development, and are _not_ necessary when embedding the Plug into a host application.\n\nPlease note that even though the `FunWithFlags.UI` module implements the `Application` behavior and comes with a proper `start/2` callback, this is not enabled by design and, in fact, the Mixfile doesn't declare an entry module.\n\nIf you really need to run it standalone in a reliable manner, you are encouraged to write your own supervision setup.\n\n#","ref":"readme.html#standalone"},{"type":"extras","title":"Security - FunWithFlags.UI","doc":"For obvious reasons, you don't want to make this web control panel publicly accessible.\n\nThe library itself doesn't provide any auth functionality because, as a Plug, it is easier to wrap it into the authentication and authorization logic of the host application.\n\nThe easiest thing to do is to protect it with HTTP Basic Auth, provided by Plug itself.\n\nFor example, in Phoenix:\n\n```diff\ndefmodule MyPhoenixAppWeb.Router do\n  use MyPhoenixAppWeb, :router\n+ import Plug.BasicAuth\n\n  pipeline :mounted_apps do\n    plug :accepts, [\"html\"]\n    plug :put_secure_browser_headers\n+   plug :basic_auth, username: \"foo\", password: \"bar\"\n  end\n\n  scope path: \"/feature-flags\" do\n    pipe_through :mounted_apps\n    forward \"/\", FunWithFlags.UI.Router, namespace: \"feature-flags\"\n  end\nend\n```","ref":"readme.html#security"},{"type":"extras","title":"Caveats - FunWithFlags.UI","doc":"While the base `fun_with_flags` library is quite relaxed in terms of valid flag names, group names and actor identifers, this web dashboard extension applies some more restrictive rules.\nThe reason is that all `fun_with_flags` cares about is that some flag and group names can be represented as an Elixir Atom, while actor IDs are just strings. Since you can use that API in your code, the library will only check that the parameters have the right type.\n\nThings change on the web, however. Think about the binary `\"Ook? Ook!\"`. In code, it can be accepted as a valid flag name:\n\n```elixir\n{:ok, true} = FunWithFlags.enable(:\"Ook? Ook!\", for_group: :\"weird, huh?\")\n```\n\nOn the web, however, the question mark makes working with URLs a bit tricky: in `http://localhost:8080/flags/Ook?%20Ook!`, the flag name will be `Ook` and the rest will be a query string.\n\nFor this reason this library enforces some stricter rules when creating flags and groups. Blank values are not allowed, `?` neither, and flag names must match `/^w+$/`.","ref":"readme.html#caveats"},{"type":"extras","title":"Installation - FunWithFlags.UI","doc":"The package can be installed by adding `fun_with_flags_ui` to your list of dependencies in `mix.exs`.  \nIt requires [`fun_with_flags`](https://hex.pm/packages/fun_with_flags), see its [installation documentation](https://github.com/tompave/fun_with_flags#installation) for more details.\n\n```elixir\ndef deps do\n  [{:fun_with_flags_ui, \"~> 0.8\"}]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}